require 'rack'
require 'pathname'
require 'sequel'
require 'net/http'

module Takana

  def self.sqlite_filepath
    if ENV['TAKANA_ENV'] == "test"
      File.expand_path("./test.db")
    else
      Pathname.new( File.expand_path("~") ).
        join("Library", "Application Support", "Edge", "takana.db").to_s
    end
  end

  def self.initialize_db
    @db = Sequel.connect("sqlite://#{URI.escape(Takana.sqlite_filepath)}") rescue nil
  
    Sequel::Model.db = @db
  end

  def self.db
    @db
  end

  def self.migrate!
    Sequel.extension :migration

    Sequel::Migrator.run(Takana.db, File.expand_path("../sassy_bunny/app/db/migrations").to_s, use_transactions: true)
  end
end

Takana.initialize_db

if Takana.db

  Takana.migrate! if ENV['TAKANA_ENV'] == "test"

  require 'rack-takana/models/project'
  require 'rack-takana/models/load_path'
  require 'rack-takana/models/compass_config'
end

require 'rack-takana/middleware'

if defined?(Rails)
  require 'rack-takana/railtie'
end